Production Order

Open Date: | 01/01/07 | Expected Start Date: |
Close Date: |  | Status | Opened
Responsible: | SalesPerson | Branch: | Stoq Roupas e Acessórios Ltda

### Production Items

Code | Item | Quantity | Produced | Lost
| Description | 1 | 0 | 0
|  | 1 | 0 | 0

### Materials

Description | Location | Needed | Lost | To Purchase | To Make
Description |  | 1 | 0 | 0 | 0
|  | 1 | 0 | 0 | 0

### Services

Code | Description | Quantity
| Description | 1